==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetSqlCollectorOperationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property collectorName Sql collector ARM name.
 * @property projectName Assessment Project Name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetSqlCollectorOperationPlainArgs(
    public val collectorName: String,
    public val projectName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs.builder()
            .collectorName(collectorName.let({ args0 -> args0 }))
            .projectName(projectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlCollectorOperationPlainArgs].
 */
@PulumiTagMarker
public class GetSqlCollectorOperationPlainArgsBuilder internal constructor() {
    private var collectorName: String? = null

    private var projectName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Sql collector ARM name.
     */
    @JvmName("vymhqyirjvfkisdh")
    public suspend fun collectorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.collectorName = mapped
    }

    /**
     * @param value Assessment Project Name
     */
    @JvmName("dkmomspcevthnewl")
    public suspend fun projectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.projectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("yimeeyhmjutaoadk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetSqlCollectorOperationPlainArgs = GetSqlCollectorOperationPlainArgs(
        collectorName = collectorName ?: throw PulumiNullFieldException("collectorName"),
        projectName = projectName ?: throw PulumiNullFieldException("projectName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetSqlCollectorOperationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property collectorName Sql collector ARM name.
 * @property projectName Assessment Project Name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class GetSqlCollectorOperationPlainArgs(
    public val collectorName: String,
    public val projectName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetSqlCollectorOperationPlainArgs.builder()
            .collectorName(collectorName.let({ args0 -> args0 }))
            .projectName(projectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSqlCollectorOperationPlainArgs].
 */
@PulumiTagMarker
public class GetSqlCollectorOperationPlainArgsBuilder internal constructor() {
    private var collectorName: String? = null

    private var projectName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Sql collector ARM name.
     */
    @JvmName("dvtwvnqoimcswkci")
    public suspend fun collectorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.collectorName = mapped
    }

    /**
     * @param value Assessment Project Name
     */
    @JvmName("uaurlfiljevjumpe")
    public suspend fun projectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.projectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("obvnjmfbkpqtqble")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetSqlCollectorOperationPlainArgs = GetSqlCollectorOperationPlainArgs(
        collectorName = collectorName ?: throw PulumiNullFieldException("collectorName"),
        projectName = projectName ?: throw PulumiNullFieldException("projectName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
